@@ -22,7 +22,7 @@ debug()
 debug "--------------------------------------------------"
 debug "Updater output:"
 
-BINPATHS="/bin /usr/bin /usr/sbin /usr/local/bin /usr/local/sbin"
+BINPATHS="/bin /usr/bin /usr/sbin /usr/local/bin /usr/local/sbin /sw/bin"
 
 for I in ${BINPATHS}; do
   J=${I}"/wget"
@@ -52,15 +52,12 @@ checkupdate()
   {
     echo -n "${FILEDESC}: "  
     UPDATEDBURL="${FIRSTMIRROR}/${VERSIONUPDATEURL}"
-    ${WGETBINARY} -q -O /tmp/rkhunter.upd ${UPDATEDBURL}
-    
-    if [ -f /tmp/rkhunter.upd ]; then
-        LATESTVERSION=`cat /tmp/rkhunter.upd`
-        rm -f /tmp/rkhunter.upd
-      else
+    LATESTVERSION="`${WGETBINARY} -q -O - ${UPDATEDBURL}`"
+    if [ "${LATESTVERSION}" = "" ]
+      then
         echo "ERROR"
         echo "Fatal error: Problem while fetching file"
-	exit 1
+        exit 1
     fi
       
     CURRENTVERSION=`cat ${DBDIR}/${FILENAME} | grep '000:version' | cut -d ':' -f3`
@@ -89,12 +86,11 @@ checkupdate()
 
 	    # Fetch file
 	    GETFILE="${FIRSTMIRROR}/${FILENAME}.gz"
-	    ${WGETBINARY} -q -O /tmp/rkhunter.upd.gz ${GETFILE}
-	    if [ $? -eq 0 ]
-	      then
-	        # Gunzip it and place it on the right location
-	        gunzip /tmp/rkhunter.upd.gz
-	        mv /tmp/rkhunter.upd ${DBDIR}/${FILENAME}
+	    TMPFILE="`mktemp /tmp/rkhunter.upd.gz.XXXXXX`" || exit 1
+	    
+	    if [ ! "`${WGETBINARY} -q -O - ${GETFILE} | gunzip -c > ${TMPFILE}`" ]
+	      then	      
+	        mv ${TMPFILE} ${DBDIR}/${FILENAME}
 		echo "  Action: Database updated (current version: ${CURRENTVERSION}, new version ${LATESTVERSION})"
 	      else
 	        echo "Fatal error: Can't retrieve file: ${GETFILE}"
@@ -126,10 +122,6 @@ if [ -f ${MIRRORFILE} ]
         rm -f ${MIRRORFILE}.new
     fi
 
-    if [ -f /tmp/rkhunter.upd ]; then
-      rm -f /tmp/rkhunter.upd
-    fi
-
     touch ${MIRRORFILE}.new
     echo "${MIRRORSVERSION}" > ${MIRRORFILE}.new
     for I in ${OTHERMIRRORS}; do
